@@ -250,11 +250,13 @@ class MLSchema(Schema):
                     mlspec_schema_version=base_version, mlspec_schema_type=base_type
                 )
             )
+
         except RegistryError:
             raise RegistryError(
                 f"""Could not find the base schema in the class \
         registry. Values provided:
         base_name = '{base_name}'
+        base_type = '{base_type}'
         schema_version = '{base_version}'"""
             )
 
@@ -331,7 +333,7 @@ class MLSchema(Schema):
         # logging.debug(f"Registry load list: {load_list}")
 
         for schema_file in load_list:
-            schema_text = schema_file.read_text()
+            schema_text = schema_file.read_text('utf-8')
             schema_dict = convert_yaml_to_dict(schema_text)
 
             if "last" in schema_dict["mlspec_schema_type"]:
@@ -368,8 +370,11 @@ class MLSchema(Schema):
         all_schemas = []
         files_with_errors = []
 
+        no_base_schemas = []
+        schemas_with_base = []
+
         for putative_schema_file in all_found_files:
-            this_text = putative_schema_file.read_text()
+            this_text = putative_schema_file.read_text('utf-8')
             try:
                 this_dict = convert_yaml_to_dict(this_text)
             except ScannerError as se:
@@ -390,7 +395,12 @@ class MLSchema(Schema):
                 )
                 continue
 
-            all_schemas.append(this_dict)
+            if "mlspec_base_type" in this_dict:
+                schemas_with_base.append(this_dict)
+            else:
+                no_base_schemas.append(this_dict)
+
+        all_schemas = no_base_schemas + schemas_with_base
 
         if len(files_with_errors) > 0:
             error_string = ""
